@@ -117,7 +117,7 @@ class AbstractDxlIO(object):
                 self.close(_force_lock=True)
 
                 if port in self.__used_ports:
-                    raise DxlError('Another instance of pypot is using the port {}. You should restart your Python kernel to pass through this issue.'.format(port))
+                    logging.warn('Another instance of pypot is using the port {}. This might be an issue in Jupyter Notebook, in that case restart the kernel.'.format(port))
 
                 # Dirty walkaround to fix a strange bug.
                 # Observed with the USB2AX on Linux with pyserial 2.7
@@ -147,7 +147,7 @@ class AbstractDxlIO(object):
         if not self.closed:
             with self.__force_lock(_force_lock) or self._serial_lock:
                 self._serial.close()
-                self.__used_ports.remove(self.port)
+                if self.port in self.__used_ports: self.__used_ports.remove(self.port)
 
             logger.info("Closing port '%s'", self.port,
                         extra={'port': self.port,
